@@ -142,7 +142,7 @@ QByteArray MBoxPrivate::escapeFrom(const QByteArray &str)
                 *d++ = '>';
             }
             // fall through
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         default:
             onlyAnglesAfterLF = false;
             break;
@@ -215,3 +215,5 @@ bool MBoxPrivate::isMBoxSeparator(const QByteArray &line) const
 }
 
 #undef STRDIM
+
+#include "moc_mbox_p.cpp"
